@@ -4,9 +4,8 @@ require 'test_helper'
 
 class TestCommandLineError < Test::Unit::TestCase
   def test_initializer
-    status = Struct.new(:to_s).new('pid 89784 exit 1')
+    status = Class.new { def to_s = 'pid 89784 exit 1' }.new
     result = Git::CommandLineResult.new(%w[git status], status, 'stdout', 'stderr')
-
     error = Git::CommandLineError.new(result)
 
     assert(error.is_a?(Git::Error))
@@ -14,7 +13,7 @@ class TestCommandLineError < Test::Unit::TestCase
   end
 
   def test_to_s
-    status = Struct.new(:to_s).new('pid 89784 exit 1')
+    status = Class.new { def to_s = 'pid 89784 exit 1' }.new
     result = Git::CommandLineResult.new(%w[git status], status, 'stdout', 'stderr')
 
     error = Git::CommandLineError.new(result)
